---
title: Sub-application error report
slug: /issues
order: 1
---

## Recommended Configuration

If you have a problem with accessing a sub-application and cannot get the sub-application export. You can first check yourself by following these steps.

1. Check if the sub-application has `provider` correctly `exported`.
2. Check if the child application is configured with the `output` configuration of `webpack`. 3.
3. If it is a `js` entry, you need to make sure that the resources of the child application are packaged as a `bundle`, if some of the dependencies are not packaged as a `bundle`, it will not load properly

```js
// webpack.config.js
{
  output: {
    libraryTarget: 'umd',
  },
}
```

3. Since `webpackjsonp` may conflict, it is possible to configure different `webpackjsonp` functions for the child application and the main application.
   :::note
   [webpack5 doesn't need this configuration](https://webpack.js.org/blog/2020-10-10-webpack-5-release/#automatic-unique-naming)
   :::

```js
// main application webpack.config.js
{
  output: {
    jsonpFunction: 'masterWebpackJsonp',
  },
}
```

```js
// Sub-application A webpack.config.js
{
  output: {
    globalObject: 'window',
    jsonpFunction: 'appAWebpackJsonp',
  },
}

```

```js
// Sub-application B webpack.config.js
{
  output: {
    globalObject: 'window',
    jsonpFunction: 'appBAWebpackJsonp',
  },
}
```

This is a problem that we will subsequently work to circumvent at the framework level to make it non-perceptible to the user.

## webpack 5

- Configure `injectClient`, otherwise webpack 5 defaults to `exports` of this `client`.
- webpack-dev-server needs to be upgraded to `4.0.0-beta.1` or higher

! [image.png](https://p-vcloud.byteimg.com/tos-cn-i-em5hxbkur4/170af76e7e7f41199b610d0ff252585a~tplv-em5hxbkur4-noop.image?width= 1316&height=574)

! [image.png](https://p-vcloud.byteimg.com/tos-cn-i-em5hxbkur4/08ccaa4185114155bc423ac64795c3c7~tplv-em5hxbkur4-noop.image?width= 2186&height=882)
